@@ -5,10 +5,10 @@ import { GET_CONFIRMATION_TEXT } from '../config/endpoints';
 import { setRoute } from '../redux/actions';
 import { connect } from 'react-redux';
 
-const Confirmation = ({ match, setRoute }) => {
+const Confirmation = ({ match, setRoute, bookingId }) => {
     const [confirmations, setConfirmations] = useState([]);
     const updated = match.params.updated === '1';
-    const bookingId = match.params.bookingId;
+    // const bookingId = match.params.bookingId;
 
     async function fetchData() {
         if (bookingId === null) return null;
@@ -60,46 +60,58 @@ const Confirmation = ({ match, setRoute }) => {
                 </p>
             </div>
             <br />
-            <p>We hope you have an enjoyable journey to/from Edinburgh Airport.</p>
+            <p>We hope you have an enjoyable journey to/from Edinburgh Airport. Our X90 coach arrives and 
+            departs from Union Street, Dundee (opposite the Malmaison Hotel) and from Stance E outside the 
+            main terminal building at Edinburgh Airport.</p>
             <p>
-                Please check your entire booking carefully and if you have any queries or questions
-                regarding any of these details please call 01382 221609/07557753057 as soon as
-                possible.
+            Please check your entire booking carefully and if you have any queries or questions regarding 
+            any of these details please call 01382 221609 or email myxplore@mcgillsbuses.co.uk as soon as 
+            possible. Phone lines are open Monday to Friday 1000 – 1700 and Saturday 1000 – 1400. 
             </p>
-            <p>Phone lines are open Monday to Friday 10.00 – 5.00 and Saturday 10.00 – 2.00.</p>
             <p>
                 <strong>
-                    Please ensure that you arrive at the coach stance
-                    <u>at least 10 minutes prior</u> to the time of departure as
-                    <u>after this time your seat may be released to other customers</u>
+                Please ensure that you arrive at the coach stance 
+                <u>at least 10 minutes prior</u> to the time
+                of your departure as <u>after this time your seat may be released to other customers</u>.
                 </strong>
             </p>
 
             <p>
                 <strong>Scottish Concessionary Card Holders and Students</strong> <br />
-                <strong>All Scottish Concessionary Card Holders</strong> must ensure that they
-                present their cards to the driver on boarding the Coach, where they will be scanned
-                on the ticket machine and the relevant concessionary ticket/s issued. Please Note:
-                If Concessionary Card/s are not available for presentation to the driver the
-                relevant standard return fare for the journey being made will be payable with no
-                refunds available on production of concession cards at a later date.
+                <strong>All Scottish Concessionary Card Holders</strong> must present their cards to the driver on boarding 
+                the Coach.   Cards will be scanned on the ticket machine and the relevant concessionary ticket/s 
+                issued.   Please Note:  If Concessionary Card/s are not available for presentation to the driver, 
+                your booking will be invalid and you will be required to pay the relevant standard fare for the 
+                journey with no refunds available on production of concession cards at a later date. 
             </p>
             <p>
                 <strong>Students</strong>
                 <br />
-                All students must show a current and valid matriculation card (or letter of
-                acceptance) to the driver prior to boarding the coach. If you do not have a Student
-                Card/Letter of Acceptance your booking will be invalid and you will be required to
-                pay the relevant standard fare for your journey.
+                All students must show a current and valid matriculation card (or letter of acceptance) to the 
+                driver prior to boarding the coach.   If you do not have a Student Card/Letter of Acceptance your 
+                booking will be invalid and you will be required to pay the relevant standard fare for your journey
+                with no refunds available on production of a student matriculation card at a later date.
             </p>
-            <p>Details of your baggage allowance can be found on your Final Confirmation</p>
+            <p>
+                <strong>Luggage Allowance</strong>
+                <br/>
+                Details of your baggage allowance can be found on your Final Confirmation</p>
             <p>
                 Terms and Conditions can be found on the
-                <a href="//www.xploremore.co.uk/">xploremore.co.uk</a> website or by contacting our
-                Travel Centre on 01382 221609.
+                <a href="//www.xploremore.co.uk/">xploremore.co.uk</a> website or by contacting our Travel 
+                Centre in Commercial Street.
             </p>
             <p>
-                For information relating to the service outwith these hours please call 07557753057
+                <strong>Booking Queries/Service Information</strong>
+                <br/>
+                Booking queries: 
+                <ul>
+                    <li>Telephone: 01382 221609</li>
+                    <li>Monday to Friday 1000 - 1700  Saturday 1000 - 1400</li>
+                </ul>
+            </p>
+            <p>
+            For information relating to service delivery outwith the above hours: 07845 785068
             </p>
             <br />
             <a
@@ -119,4 +131,12 @@ const Confirmation = ({ match, setRoute }) => {
     );
 };
 
-export default connect(null, { setRoute })(Confirmation);
+const mapStateToProps = state => {
+    const bookingId = state.booking.bookingId;
+
+    return {
+        bookingId
+    };
+};
+
+export default connect(mapStateToProps, { setRoute })(Confirmation);
